#include <iostream>
#include <array>
#include <algorithm>

struct Point {
	int r, c;
};

std::istream& operator >> (std::istream& is, Point& p) noexcept {
	return is >> p.r >> p.c;
}

int h, w, k;

const int MAX_N_POINTS = 100'100;
std::array<Point, MAX_N_POINTS> images;

void input_data() noexcept {
	std::ios_base::sync_with_stdio(false);
	std::cin.tie(nullptr);


	std::cin >> h >> w >> k;

	for (int i = 0; i < k; ++i)
		std::cin >> images[i];
}

std::array<int, MAX_N_POINTS> solve_indices;

template <typename Proj>
std::pair<int, int> solveFor(Proj&& proj, int screen_size) noexcept {
	std::sort(solve_indices.begin(), solve_indices.begin() + k, [&proj](int lhs, int rhs) {
		return std::invoke(proj, images[lhs]) < std::invoke(proj, images[rhs]);
	});

	int best_shift = 0, best_size = std::invoke(proj, images[solve_indices[k - 1]]) - std::invoke(proj, images[solve_indices[0]]) + 1;
	for (int shift = 1; shift < k; ++shift) {
		int pos1 = std::invoke(proj, images[solve_indices[shift - 1]]) + screen_size;
		int pos2 = std::invoke(proj, images[solve_indices[shift]]);
		int size = pos1 - pos2 + 1;
		if (size < best_size) {
			best_size = size;
			best_shift = shift;
		}
	}

	int keys = 0;
	if (best_shift > 0) {
		int distance = std::invoke(proj, images[solve_indices[best_shift - 1]]);
		keys = std::min(distance, h - distance);
	}

	return { best_size, keys };
}

std::pair<int, int> solve() noexcept {
	for (int i = 0; i < k; ++i)
		solve_indices[i] = i;

	auto [sizeR, keysR] = solveFor(&Point::r, h);
	auto [sizeC, keysC] = solveFor(&Point::c, w);

	return { sizeC * sizeR, keysR + keysC };
}

int main() {
	input_data();
	auto [size, keys] = solve();
	std::cout << size << ' ' << keys;
	return 0;
}
