#include <iostream>
#include <array>
#include <algorithm>

struct Point {
	int r, c;
};

std::istream& operator >> (std::istream& is, Point& p) noexcept {
	is >> p.r >> p.c;
	--p.r;
	--p.c;
	return is;
}

int h, w, k;

const int MAX_N_POINTS = 100'100;
std::array<Point, MAX_N_POINTS> images;

void input_data() noexcept {
	std::ios_base::sync_with_stdio(false);
	std::cin.tie(nullptr);


	std::cin >> h >> w >> k;

	for (int i = 0; i < k; ++i)
		std::cin >> images[i];
}

std::pair<int, int> solve() noexcept {
	int best_size = 2e9, best_keys = 0;
	for (int dr = 0; dr < h; ++dr)
		for (int dc = 0; dc < w; ++dc) {
			int min_r = 2e9, max_r = 0, min_c = 2e9, max_c = 0;
			for (int i = 0; i < k; ++i) {
				int r = (images[i].r + dr) % h;
				int c = (images[i].c + dc) % w;

				min_r = std::min(r, min_r);
				max_r = std::max(r, max_r);
				min_c = std::min(c, min_c);
				max_c = std::max(c, max_c);
			}

			int size = (max_r - min_r + 1) * (max_c - min_c + 1);
			int keys = std::min(dr, h - dr) + std::min(dc, w - dc);

			if (size < best_size || size == best_size && keys < best_keys) {
				best_size = size;
				best_keys = keys;
			}
		}

	return { best_size, best_keys };
}

int main() {
	input_data();
	auto [size, keys] = solve();
	std::cout << size << ' ' << keys;
	return 0;
}
