#include <iostream>
#include <array>
#include <map>
#include <tuple>

int64_t n, q;
std::array<int64_t, 200'100> weights;

void input_data() noexcept {
	std::cin >> n >> q;
	for (int64_t i = 0; i < n; ++i) {
		std::cin >> weights[i];
	}
}

int64_t min_k_for_accessable(int64_t a, int64_t b, int64_t i = n - 1) noexcept {
	if (a == 0 && b == 0) return 0;
	if (i == -1 || a < 0 || b < 0) return 2e18;

	using CacheKey = std::pair<int64_t, std::pair<int64_t, int64_t>>;
	static std::map<CacheKey, int64_t> cache;

	auto iter = cache.find({ a, {b, i} });
	if (iter != cache.end()) return iter->second;

	int64_t min_k_included = std::max(std::min(min_k_for_accessable(a - weights[i], b, i - 1), 
											   min_k_for_accessable(a, b - weights[i], i - 1)), weights[i]);
	int64_t min_k = std::min(min_k_included, min_k_for_accessable(a, b, i - 1));

	cache.emplace(CacheKey{ a, {b, i} }, min_k);
	return min_k;
}

int64_t min_k_for_ideal(int64_t a, int64_t b) noexcept {
	using CacheKey = std::pair<int64_t, int64_t>;
	static std::map<CacheKey, int64_t> cache;

	auto iter = cache.find({ a, b});
	if (iter != cache.end()) return iter->second;

	int64_t min_k = min_k_for_accessable(a, b);
	if (a > 0) min_k = std::max(min_k_for_ideal(a - 1, b), min_k);
	if (b > 0) min_k = std::max(min_k_for_ideal(a, b - 1), min_k);

	cache.emplace(CacheKey{ a, b }, min_k);
	return min_k;
}

bool solve(int64_t k, int64_t a, int64_t b) noexcept {
	return min_k_for_ideal(a, b) <= k;
}

void process_queries() noexcept {
	int64_t z;
	std::cin >> z;
	int64_t v = 0;
	for (int64_t qi = 0; qi < q; ++qi) {
		int64_t j, c, d;
		std::cin >> j >> c >> d;

		int64_t k = j - v * z, a = c - v * z, b = d - v * z;

		if (solve(k, a, b)) {
			++v;
			std::cout << "Yes\n";
		}
		else
			std::cout << "No\n";
	}
}

int main() {
	std::ios_base::sync_with_stdio(false);
	std::cin.tie(nullptr);

	input_data();

	process_queries();
}
