#include <iostream>
#include <vector>
#include <algorithm>
#include <set>
#include <map>

#define int long long

struct SegTree {
    int n;
    std::vector<int> tree;
    SegTree(int s) {
        n = 2;
        while (n <= s) {
            n *= 2;
        }
        tree.resize(n * 2);
        for (int i = n - 1; i < n - 1 + s; i++) {
            tree[i] = 1;
        }
        for (int i = n - 2; i >= 0; i--) {
            tree[i] = tree[i * 2 + 1] + tree[i * 2 + 2];
        }
    }
    void set(int node, int l, int r, int idx) {
        if (idx < l || r <= idx) {
            return;
        }
        if (l + 1 >= r) {
            tree[node] = 0;
            return;
        }
        int mid = (l + r) / 2;
        if (idx < mid) {
            set(node * 2 + 1, l, mid, idx);
        } else {
            set(node * 2 + 2, mid, r, idx);
        }
        tree[node]--;
    }
    int get_left(int node, int l, int r, int L, int R) {
        if (node > tree.size()) {
            return -1;
        }
        if (tree[node] == 0) return -1;
        if (r <= L || R <= l) return -1;
        if (l + 1 == r) {
            return node - n + 1;
        }
        int mid = (l + r) / 2;
        int v = get_left(node * 2 + 1, l, mid, L, R);
        if (v == -1) {
            return get_left(node * 2 + 2, mid, r, L, R);
        }
        return v;
    }
    int get_right(int node, int l, int r, int L, int R) {
        if (node > tree.size()) {
            return -1;
        }
        if (tree[node] == 0) return -1;
        if (r <= L || R <= l) return -1;
        if (l + 1 == r) {
            return node - n + 1;
        }
        int mid = (l + r) / 2;
        int v = get_right(node * 2 + 2, mid, r, L, R);
        if (v == -1) {
            return get_right(node * 2 + 1, l, mid, L, R);
        }
        return v;
    }
    void set(int idx) {
        set(0, 0, n, idx);
    }
    int get_left(int l, int r) {
        return get_left(0, 0, n, l, r);
    }
    int get_right(int l, int r) {
        return get_right(0, 0, n, l, r);
    }
};

inline void slave1() {
    int n, k;
    std::cin >> n >> k;
    SegTree st(n);
    std::vector<int> a(k);
    for (auto &e : a) {
        std::cin >> e;
        e--;
        st.set(e);
    }
    std::set<int> res;
    for (auto e : a) {
        int i = st.get_right(0, e);
        if (i == -1 || i >= n) {
            i = st.get_right(e, n);
        }
        st.set(i);
        res.insert(i);
    }
    for (auto e : res) {
        std::cout << e + 1 << ' ';
    }
    std::cout << std::endl;
}

inline void slave2() {
    int n, k;
    std::cin >> n >> k;
    SegTree st(n);
    std::vector<int> a(k);
    for (auto &e : a) {
        std::cin >> e;
        e--;
        st.set(e);
    }
    std::set<int> res;
    for (auto e : a) {
        int i = st.get_left(e, n);
        if (i == -1 || i >= n) {
            i = st.get_left(0, e);
        }
        st.set(i);
        res.insert(i);
    }
    for (auto e : res) {
        std::cout << e + 1 << ' ';
    }
    std::cout << std::endl;
}

signed main() {
    std::cin.tie(nullptr)->sync_with_stdio(false);
    int type;
    std::cin >> type;
    int t;
    std::cin >> t;
    if (type == 1) {
        while (t-- > 0) {
            slave1();
        }
    } else {
        while (t-- > 0) {
            slave2();
        }
    }
    return 0;
}

/*
2
1
5 2
1 5
*/