#include <iostream>
#include <vector>
#include <unordered_set>
#include <algorithm>
#include <set>

using namespace std;
typedef long long ll;
typedef pair<ll, ll> pll;
typedef pair<pll, ll> segment;
ll t, n, a;
vector<segment> segments;
vector<ll> maxLenFromHere(n, 0);
vector<ll> inc;
vector<ll> cnt;

const ll DELETE = -1;
const ll ADD = 1;

struct Event {
    ll coord, type, segmentNumber;

    Event(ll coord, ll type, ll segmentNumber) : coord(coord), type(type), segmentNumber(segmentNumber) {};

    Event() : coord(0), type(0), segmentNumber(0) {};
};


bool cmpSegments(segment &s1, segment &s2) {
    return s1.first.second < s2.first.second;
}

bool cmpToRemove(segment &s1, segment &s2) {
    return cnt[s1.second] > cnt[s2.second];
}

void recurse(ll length, ll segmentNumber, ll lastCoord) {
    ll leftLength = a - length + 1;
    ll maxLength = maxLenFromHere[segmentNumber];
    if (maxLength + 1 < leftLength) {
        // никак нельзя получить запрещённую последовательность
        return;
    }
    auto seg = segments[segmentNumber];
    ll l = seg.first.first;
    ll r = seg.first.second;
    if (l <= lastCoord) return;
    inc.push_back(seg.second);
    if (leftLength - 1 <= 0) {
        // составили запрещённую последовательность
        for (auto seg: inc) {
//            cout << seg << ' ';
            ++cnt[seg];
        }
//        cout << endl;
    }

    for (ll i = segmentNumber + 1; i < n; ++i) {
        recurse(length + 1, i, r);
    }
    inc.pop_back();
}

int main() {
    cin >> t;
    for (ll tn = 0; tn < t; ++tn) {
        cin >> n;
        segments.resize(n);
        cnt.resize(n, 0);
        // для каждого отрезка считаем количество пересечений с помощью сканирующей прямой
        for (ll i = 0; i < n; ++i) {
            cnt[i] = 0;
            ll l, r;
            cin >> l >> r;
            segments[i] = {{l, r}, i};
        }
        // ----
        // т. к. нам нужно будет удалять отрезки, формируем множество
        // чтобы иметь правильную сортировку, меняем левую и правую границу местами
        set<segment> segments_set;
        for (auto item: segments) {
            segments_set.insert({{item.first.second, item.first.first}, item.second});
        }
        // ищем цепочку
        auto segmentPointer = segments_set.begin();
        set<segment> included;
        included.insert(*(segments_set.begin()));
        ll lastIncludedCoord = (*(segments_set.begin())).first.first;
        ++segmentPointer;

        while (segmentPointer != segments_set.end()) {
            auto testedSegment = *segmentPointer;
            ll l = testedSegment.first.second;
            ll r = testedSegment.first.first;
            if (l > lastIncludedCoord) {
                // мы можем взять этот отрезок
                included.insert(testedSegment);
                lastIncludedCoord = r;
            }
            ++segmentPointer;
        }

        ll m = included.size();
        a = m / 2;

        // для каждого отрезка смотрим, в каком количестве запрещённых последовательностей он состоит
        maxLenFromHere.resize(n, 0);
        sort(segments.begin(), segments.end(), cmpSegments);
        // для каждого сегмента ищм максимальную длину последовательности из него
        for (ll startSegment = n - 1; startSegment >= 0; --startSegment) {
            auto ss = segments[startSegment];
            ll sttn = startSegment + 1;
            ll length = 0;
            ll lastCoord = ss.first.second;
            while (sttn < n) {
                auto stt = segments[sttn];
                ll l = stt.first.first;
                if (l > lastCoord) {
                    length = max(length, maxLenFromHere[sttn] + 1);
                }
                ++sttn;
            }
            maxLenFromHere[startSegment] = length;
        }
//        cout << "a is " << a << endl;
        for (ll start = 0; start < n; ++start) {
            recurse(0, start, -1);
        }
//        cout << "----------" << endl;
//        for (ll i = 0; i < n; ++i) {
//            cout << cnt[i] << endl;
//        }
//        cout << "----------" << endl;
//        return 0;

        // удаляем неподходящие отрезки
        while (true) {
            auto segmentPointer = segments_set.begin();
            set<segment> included;
            included.insert(*(segments_set.begin()));
            ll lastIncludedCoord = (*(segments_set.begin())).first.first;
            ++segmentPointer;


            while (segmentPointer != segments_set.end()) {
                auto testedSegment = *segmentPointer;
                ll l = testedSegment.first.second;
                ll r = testedSegment.first.first;
                if (l > lastIncludedCoord) {
                    // мы можем взять этот отрезок
                    included.insert(testedSegment);
                    lastIncludedCoord = r;
                }
                ++segmentPointer;
            }

            ll length = included.size();

            if (length > a) {
                // формируем список кандидатов на удаление в правильном порядке
                vector<segment> to_remove(included.size());
                auto p = included.begin();
                for (ll i = 0; i < length; ++i) {
                    to_remove[i] = *p;
                    ++p;
                }
                sort(to_remove.begin(), to_remove.end(), cmpToRemove);
                ll to_remove_count = length - a;
                for (ll i = 0; i < to_remove_count; ++i) {
                    segment s = to_remove[i];
                    segments_set.erase(segments_set.find(s));
                }
            } else {
                ll current_segments_count = segments_set.size();
                if (current_segments_count > n / 2) {
                    // удаляем любые отрезки, не находящиеся в текущей цепочке
                    for (auto seg: segments) {
                        if (segments_set.size() == n / 2) break;
                        segment ss = {{seg.first.second, seg.first.first}, seg.second};
                        if (!included.count(ss) && segments_set.count(ss)) {
                            segments_set.erase(segments_set.find(ss));
                        }
                    }
                }
                break;
            }
        }
        for (auto seg: segments_set) {
            cout << seg.second + 1 << ' ';
        }
        cout << endl;
    }
}