#include <iostream>
#include <vector>
#include <algorithm>
#include <cmath>
#include <string>
#include <numeric>
#include <cassert>

using namespace std;

typedef pair<int, int> pii;

#define All(x) (x).begin(), (x).end()
#define X first
#define Y second

struct segment {
	pii s;
	int id;

	segment() {}
	segment(int x, int y) {
		s = { x, y };
		id = -1;
	}
};

const int INF = 1e9 + 179;

bool cmp(segment& a, segment& b) {
	if (a.s.Y == b.s.Y) return a.s.X > b.s.X;
	return a.s.Y < b.s.Y;
}

bool intersect(segment& a, segment& b) {
	return !(a.s.X > b.s.Y || a.s.Y < b.s.X);
}

void solve() {
	int n;
	cin >> n;
	vector<segment> seg(n);
	for (int i = 0; i < n; i++) {
		cin >> seg[i].s.X >> seg[i].s.Y;
		seg[i].id = i + 1;
	}
	sort(All(seg), cmp);
	int m = 1, last = seg[0].s.Y;
	for (int i = 1; i < n; i++) {
		if (seg[i].s.X > last) {
			m++;
			last = seg[i].s.Y;
		}
	}
	if (n <= 500) {
		vector<pii> cnt;
		for (int i = 0; i < n; i++) {
			int cur = 0;
			for (int j = 0; j < n; j++) {
				cur += intersect(seg[i], seg[j]);
			}
			cnt.emplace_back(cur, i);
		}
		vector<int> ban(n);
		sort(All(cnt));
		for (int i = 0; i < n/2; i++) {
			ban[cnt[i].Y] = 1;
		}
		int new_m = 0, last = -1;
		for (int i = 0; i < n; i++) {
			if (!ban[i] && seg[i].s.X > last) {
				new_m++;
				last = seg[i].s.Y;
			}
		}
		assert(new_m <= m / 2);

		seg.emplace_back(INF, INF);
		n++;
		vector<vector<int>> dp(n + 1, vector<int>(n / 2 + 1, INF));
		vector<vector<pii>> prev(n + 1, vector<pii>(n / 2 + 1));
		dp[0][0] = 0;
		for (int i = 1; i <= n; i++) {
			for (int j = i - 1; j >= 0; j--) {
				int prev_r = -1;
				if (j >= 1) {
					prev_r = seg[j - 1].s.Y;
				}
				if (prev_r >= seg[i - 1].s.X) continue;
				int off = 0;
				for (int k = j + 1; k < i; k++) {
					off += (seg[k - 1].s.X > prev_r);
				}

				auto meq = [&prev, &dp](int i1, int cnt1, int i2, int cnt2) {
					int val = dp[i2][cnt2] + 1;
					if (dp[i1][cnt1] > val) {
						dp[i1][cnt1] = val;
						prev[i1][cnt1] = { i2, cnt2 };
					}
				};

				for (int cnt = n / 2; cnt - off >= 0; cnt--) {
					meq(i, cnt, j, cnt - off);
				}
			}
		}
		pii state = { n, 0 };
		while (dp[state.X][state.Y] > m / 2 + 1)
			state.Y++;
		vector<int> ans, extra;
		while (state.X > 0) {
			pii next = prev[state.X][state.Y];
			int i1 = state.X;
			int i2 = next.X;
			if (i1 < n)
				ans.push_back(seg[i1 - 1].id);
			int next_r = -1;
			if (i2 - 1 >= 0)
				next_r = seg[i2 - 1].s.Y;
			for (int i = i2 + 1; i < i1; i++) {
				if (seg[i - 1].s.X <= next_r)
					extra.push_back(seg[i - 1].id);
			}
			state = next;
		}
		for (int f : extra)
			ans.push_back(f);
		while (ans.size() > n / 2)
			ans.pop_back();
		for (int x : ans)
			cout << x << ' ';
		cout << '\n';
	}
	else {
		for (int i = 0; i < n / 2; i++)
			cout << seg[i].id << ' ';
		cout << '\n';
	}
}

signed main()
{
	int t;
	cin >> t;
	while (t--)
		solve();
}