#include <iostream>
#include <vector>
#include <algorithm>
using namespace std;

const int MAXN = 200809;

struct node {
    node* l = nullptr;
    node* r = nullptr;
    int val;
    int prior;
    int sz = 1;
};

node* copy(node* nd) {
    node* cnd = new node();
    cnd->l = nd->l;
    cnd->r = nd->r;
    cnd->val = nd->val;
    cnd->prior = nd->prior;
    cnd->sz = nd->sz;
    return cnd;
}

int gsz(node* nd) {
    if (!nd)
        return 0;
    return nd->sz;
}

void update(node* nd) {
    nd->sz = 1 + gsz(nd->l) + gsz(nd->r);
}

pair<node*, node*> split(node* nd, int val) {
    if (!nd)
        return {nd, nd};
    nd = copy(nd);
    if (val <= nd->val) {
        auto [l, r] = split(nd->l, val);
        nd->l = r;
        update(nd);
        return {l, nd};
    } else {
        auto [l, r] = split(nd->r, val);
        nd->r = l;
        update(nd);
        return {nd, r};
    }
}

node* merge(node* l, node* r) {
    if (!l)
        return r;
    if (!r)
        return l;
    if (l->prior > r->prior) {
        auto lr = merge(l->r, r);
        l = copy(l);
        l->r = lr;
        update(l);
        return l;
    } else {
        auto rl = merge(l, r->l);
        r = copy(r);
        r->l = rl;
        update(r);
        return r;
    }
}

const int FAILST = 17701333;

pair<int, int> lower_bound(node* nd, int val) {
    if (!nd)
        return {0, FAILST};
    if (nd->val == val)
        return {gsz(nd->l), nd->val};
    if (val < nd->val) {
        pair<int, int> ans = lower_bound(nd->l, val);
        if (ans.second == FAILST)
            return {gsz(nd->l), nd->val}; 
        else
            return ans;
    }
    pair<int, int> ans = lower_bound(nd->r, val);
    ans.first += gsz(nd->l) + 1;
    return ans;
}

pair<int, int> get_less(node* nd, int val) {
    if (!nd)
        return {0, FAILST};
    if (nd->val == val)
        return {gsz(nd->l), nd->val};
    if (val < nd->val)
        return get_less(nd->l, val);
    pair<int, int> ans = get_less(nd->r, val);
    if (ans.second == FAILST)
        return {gsz(nd->l), nd->val};
    ans.first += gsz(nd->l) + 1;
    return ans;
}

node* insert(node* rt, int val) {
    node* nd = new node();
    nd->prior = rand();
    nd->val = val;
    auto [l, r] = split(rt, val);
    return merge(l, merge(nd, r));
}

node* erase(node* rt, int val) {
    auto [l, r] = split(rt, val);
    r = split(r, val + 1).second;
    return merge(l, r);
}

int p[MAXN];
int mnsf[MAXN];
int mxsf[MAXN];
node* incsf[MAXN];
node* decsf[MAXN];

int get_greed(int n, int i, int a, int b) {
    int inc = gsz(incsf[i]) - lower_bound(incsf[i], a).first - 1;
    int dec = lower_bound(decsf[i], b + 1).first;
    return inc + dec;
}

int brute_force(int n, int i, int a, int b) {
    if (i >= n) {
        if (a == 0 || b == n + 1)
            return -MAXN;
        return 0;
    }
    int ans = 0;
    if ((a > 0 || mxsf[i] >= b) && (b <= n || mnsf[i] <= a))
        ans = get_greed(n, i, b, a);
    if (a <= p[i] && p[i] <= b) {
        ans = max(ans, 1 + brute_force(n, i + 1, p[i], b));
        ans = max(ans, 1 + brute_force(n, i + 1, a, p[i]));
    } else {
        ans = max(ans, brute_force(n, i + 1, a, b));
        if (p[i] >= b)
            ans = max(ans, get_greed(n, i, p[i], b));
        if (p[i] <= a)
            ans = max(ans, get_greed(n, i, a, p[i]));
    }
    return ans;
}

void solve() {
    int n;
    cin >> n;
    for (int i = 0; i < n; ++i) {
        cin >> p[i];
    }
    mnsf[n - 1] = mxsf[n - 1] = p[n - 1];
    for (int i = n - 2; i >= 0; --i) {
        mnsf[i] = min(mnsf[i], mnsf[i + 1]);
        mxsf[i] = max(mxsf[i], mxsf[i + 1]);
    }
    incsf[n] = insert(nullptr, MAXN);
    for (int i = n - 1; i >= 0; --i) {
        incsf[i] = incsf[i + 1];
        pair<int, int> it = get_less(incsf[i], p[i]);
        if (it.second != FAILST)
            incsf[i] = erase(incsf[i], it.second);
        incsf[i] = insert(incsf[i], p[i]);
    }
    incsf[n] = insert(nullptr, -MAXN);
    for (int i = n - 1; i >= 0; --i) {
        decsf[i] = decsf[i + 1];
        pair<int, int> it = lower_bound(decsf[i], p[i] + 1);
        if (it.second != FAILST) {
            decsf[i] = erase(decsf[i], it.second);
        }
        decsf[i] = insert(decsf[i], p[i]);
    }
    cout << brute_force(n, 0, 0, n + 1) << '\n';
    for (int i = 0; i <= n; ++i)
        incsf[i] = decsf[i] = nullptr;
}

signed main() {
    int t;
    cin >> t;
    while (t--) {
        solve();
    }
}
