#include <iostream>
#include <vector>
#include <bitset>
#include <algorithm>
using namespace std;
using ll = long long;

vector<pair<ll, ll>> convex_hull_rect(vector<pair<ll, ll>> v) {
    vector<pair<ll, ll>> ans;
    for (auto p : v) {
        p.first = min(p.first, 2000ll);
        p.second = min(p.second, 2000ll);
        while (ans.size() && ans.back().second <= p.second)
            ans.pop_back();
        if (ans.empty() || ans.back().first < p.first)
            ans.push_back(p);
    }
    return ans;
}

vector<pair<ll, ll>> merge(vector<pair<ll, ll>>& a, vector<pair<ll, ll>>& b) {
    vector<pair<ll, ll>> ans(a.size() + b.size());
    merge(a.begin(), a.end(), b.begin(), b.end(), ans.begin());
    return ans;
}

vector<pair<ll, ll>> get_ndp(vector<pair<ll, ll>>& dp, ll w) {
    int n = dp.size();
    vector<pair<ll, ll>> ansup;
    vector<pair<ll, ll>> ansdown;
    bool isok = false;
    for (int i = 0; i < n; ++i) {
        isok = isok | (dp[i].first + 1 >= w && dp[i].second + 1 >= w);
    }
    for (int i = 0; i < n; ++i) {
        if (dp[i].second + 1 >= w || isok) {
            ansup.push_back({dp[i].first, dp[i].second + w});
            continue;
        }
    }
    for (int i = n - 1; i >= 0; --i) {
        if (dp[i].first + 1 >= w || isok) {
            ansdown.push_back({dp[i].first + w, dp[i].second});
            continue;
        }
    }
    reverse(ansdown.begin(), ansdown.end());
    ansup = merge(ansup, dp);
    ansup = merge(ansup, ansdown);
    return convex_hull_rect(ansup);
}

const int MAXN = 3e5 + 123;
vector<pair<ll, ll>> dp_[MAXN];
vector<pair<ll, ll>>* dp = dp_ + 1;

signed main() {
    int n, q;
    cin >> n >> q;
    vector<ll> ws(n);
    for (int i = 0; i < n; ++i)
        cin >> ws[i];
    ll z;
    cin >> z;
    sort(ws.begin(), ws.end());
    dp[-1] = {{0, 0}};
    for (int i = 0; i < n; ++i) {
        dp[i] = get_ndp(dp[i - 1], ws[i]);
    }
    // cout << dp[n - 1].size() << '\n';
    while (q--) {
        ll k, a, b;
        cin >> k >> a >> b;
        int ki = upper_bound(ws.begin(), ws.end(), k) - ws.begin();
        --ki;
        auto it = lower_bound(dp[ki].begin(), dp[ki].end(), pair<ll, ll>(a, -1));
        if (it == dp[ki].end() || b > it->second)
            cout << "No\n";
        else
            cout << "Yes\n";
    }

}
