#include <bits/stdc++.h>

using namespace std;
using ll = long long;

void ckmax(int &x, int y) {
    if (x < y) {
        x = y;
    }
}

void ckmin(int &x, int y) {
    if (x > y) {
        x = y;
    }
}

constexpr int inf = 1e8;

struct SegTreeMax {
    vector<int> t;
    int sz;

    void init(int n) {
        sz = n;
        t.assign(sz << 1, -inf);
    }

    void modify(int x, int i) {
        for (t[x += sz] = i; x >>= 1;) {
            t[x] = max(t[x << 1], t[x << 1 | 1]);
        }
    }

    int rangeMax(int l, int r) {
        int ans = -inf;
        for (l += sz, r += sz; l < r; l >>= 1, r >>= 1) {
            if (l & 1) ckmax(ans, t[l++]);
            if (r & 1) ckmax(ans, t[--r]);
        }
        return ans;
    }
};

struct SegTreeMin {
    vector<int> t;
    int sz;

    void init(int n) {
        sz = n;
        t.assign(sz << 1, inf);
    }

    void modify(int x, int i) {
        for (t[x += sz] = i; x >>= 1;) {
            t[x] = min(t[x << 1], t[x << 1 | 1]);
        }
    }

    int rangeMin(int l, int r) {
        int ans = inf;
        for (l += sz, r += sz; l < r; l >>= 1, r >>= 1) {
            if (l & 1) ckmin(ans, t[l++]);
            if (r & 1) ckmin(ans, t[--r]);
        }
        return ans;
    }
};

struct Info {
    int a = -inf, b = -inf, c = -inf, ab = -inf, bc = -inf, cb = -inf, ac = -inf, abc = -inf;
};

Info operator+(const Info &l, const Info &r) {
    Info res{};
    res.a = max(l.a, r.a), res.b = max(l.b, r.b), res.c = max(l.c, r.c);
    res.ab = max({l.ab, l.a + r.b, r.ab});
    res.bc = max({l.bc, l.b + r.c, r.bc});
    res.abc = max({l.abc, l.ab + r.c, l.a + r.bc, r.abc});

    res.cb = max({l.c + r.b, r.cb, l.cb});
    res.ac = max({l.a + r.c, l.ac, r.ac});
    res.abc = max({res.abc, l.ac + r.b, l.a + r.cb});
    return res;
}

struct SegmentTree {
    vector<Info> t;
    int sz = 1;

    void init(int n) {
        sz = 1 << __lg(n) + !!(n & (n - 1));
        t.assign(sz << 1, Info());
    }

    void modify(int x, int i, int type) {
        x += sz;
        (type == 0 ? t[x].a : type == 1 ? t[x].b : t[x].c) = i;

        for (; x >>= 1;) {
            t[x] = t[x << 1] + t[x << 1 | 1];
        }
    }

    Info rangeQuery(int l, int r, int x, int lx, int rx) {
        if (l >= rx || lx >= r) {
            return {};
        }
        if (l <= lx && rx <= r) {
            return t[x];
        }

        int mid = lx + rx >> 1;
        return rangeQuery(l, r, x << 1, lx, mid) + rangeQuery(l, r, x << 1 | 1, mid, rx);
    }

    Info rangeQuery(int l, int r) {
        return rangeQuery(l, r, 1, 0, sz);
    }
};

int smrt(vector<int> a) {
//    cout << "a: \n";

//    for (int x : a) cout << x << " ";
//    cout << endl;

    int n = a.size();

    vector<int> ord(n, -1);

    for (int i = 0; i < n; ++i) {
        assert(a[i] >= 0 && a[i] < n && ord[a[i]] == -1);
        ord[a[i]] = i;
    }


    vector<int> prefInc(n, -inf), prefDec(n, -inf), sufInc(n, -inf), sufDec(n, -inf);

    SegTreeMax stMaxPref, stMaxSuf;
    stMaxPref.init(n), stMaxSuf.init(n);

    for (int x = 0; x < n; ++x) {
        int i = ord[x];

        sufDec[i] = max(0, stMaxSuf.rangeMax(i + 1, n)) + 1;

        stMaxSuf.modify(i, sufDec[i]);
    }

    stMaxPref.init(n), stMaxSuf.init(n);

    for (int x = n - 1; x >= 0; --x) {
        int i = ord[x];

        sufInc[i] = max(0, stMaxSuf.rangeMax(i + 1, n)) + 1;

        stMaxSuf.modify(i, sufInc[i]);
    }

    SegTreeMax stMax;
    stMax.init(n);

    SegTreeMin stMin;
    stMin.init(n);

    vector<int> incPrefRecord(n), decPrefRecord(n);

    vector<array<int, 3>> queries; //val, i, additional

    for (int i = 0; i < n; ++i) {
        int j = stMax.rangeMax(0, a[i]);

        if (j >= 0) {
            incPrefRecord[i] = incPrefRecord[ord[j]] + 1;
        } else {
            incPrefRecord[i] = 1;
        }

        j = stMin.rangeMin(a[i] + 1, n);


        if (j < n) {
            decPrefRecord[i] = decPrefRecord[ord[j]] + 1;
        } else {
            decPrefRecord[i] = 1;
        }

        // end of inc
        j = stMin.rangeMin(a[i] + 1, n);
        int val = j >= n ? 0 : decPrefRecord[ord[j]];

        if (j < n) {
            val += incPrefRecord[i];

            queries.push_back({a[i], i, val});
            queries.push_back({j, i, val});
        }

        //end of dec
        j = stMax.rangeMax(0, a[i]);

        if (j >= 0) {
            val = j < 0 ? 0 : incPrefRecord[ord[j]];
            val += decPrefRecord[i];

            queries.push_back({j, i, val});
            queries.push_back({a[i], i, val});
        }

        stMax.modify(a[i], a[i]);
        stMin.modify(a[i], a[i]);
    }

    SegmentTree st;
    st.init(n + 1);

    st.modify(n, 0, 1);
    st.modify(n, 0, 2);

    sort(queries.begin(), queries.end());

    for (int x = 0; x < n; ++x) {
        st.modify(ord[x], sufInc[ord[x]], 2);
    }

    int last = -1;
    int ans = 0;

    for (auto [x, i, add]: queries) {
        while (last < x) {
            if (last >= 0) {
                st.modify(ord[last], sufDec[ord[last]], 1);
            }

            last += 1;

            st.modify(ord[last], -inf, 2);
        }

        Info R = st.rangeQuery(i + 1, n + 1);

        int now = max(R.bc, R.cb);

        ans = max(ans, add + now);
    }

    return ans;
}

int stupid(vector<int> a) {
    int n = a.size();

    vector dp(n + 3, vector<int>(n + 3, -inf)), dq(dp);

    dp[n + 1][0] = 0;

    for (int i = 0; i < n; ++i) {
        dq = dp;
        dp = vector(n + 3, vector<int>(n + 3, -inf));

        for (int x = 0; x <= n + 1; ++x) {
            for (int y = 0; y <= n + 1; ++y) {
                ckmax(dp[min(x, a[i])][y], dq[x][y] + (x > a[i]));
                ckmax(dp[x][max(y, a[i])], dq[x][y] + (y < a[i]));
            }
        }
    }

    int ans = -10;

    for (int x = 0; x <= n + 1; ++x) {
        for (int y = 0; y <= n + 1; ++y) {
            if (x >= 1 && x <= n && y >= 1 && y <= n) {
                ckmax(ans, dp[x][y]);
            }
        }
    }

    return ans;
}

int smart(vector<int> a) {
    int n = a.size();

    if (1) {
        vector<int> b;
        b.push_back(1);
        b.push_back(n + 3);

        for (int i = 0; i < n; ++i) {
            b.push_back(a[i] + 1);
        }

        b.push_back(0);
        b.push_back(n + 2);

        int ans = smrt(b);
        ans -= 4;

        assert(ans >= 1 && ans <= n);
        return ans;
    } else {
        for (int &x : a) {
            x -= 1;
        }

        int ans = smrt(a);

        return ans;
    }
}

mt19937 rnd(228);

int rand(int l, int r) {
    return rnd() % (r - l) + l;
}

void stress() {
    int ok = 0;

    while (true) {
        int n = rand(2, 7);
        vector<int> a(n);
        iota(a.begin(), a.end(), 1);

        shuffle(a.begin(), a.end(), rnd);

        int correct = stupid(a);
        int wrong = smart(a);

        if (correct != wrong) {
            cout << "Found: \n";

            cout << "correct: " << correct << endl;
            cout << "wrong: " << wrong << endl;

            cout << n << endl;

            for (int x : a) cout << x << " ";

            cout << endl;

            exit(0);
        }

        if (++ok % 100 == 0) {
            cout << "OK: " << ok << endl;
        }
    }
}

void solve() {
    int n;
    cin >> n;

    vector<int> a(n);

    for (int i = 0; i < n; ++i) {
        cin >> a[i];
    }

    cout << smart(a) << '\n';
}

int main() {
    ios::sync_with_stdio(false);
    cin.tie(nullptr);

    if (1) {
        int test = 1;
        cin >> test;

        while (test--) {
            solve();
        }
    } else {
        stress();
    }

    return 0;
}
