#include <iostream>
#include <vector>

using namespace std;

struct FenwickTree {
    vector<int> tree;
    int sz;
    
    FenwickTree(int n) {
        tree.resize(n + 1);
        sz = n;
    }

    void _update(int i, int x) {
        for (; i <= sz; i += i & -i) {
            tree[i] = max(tree[i], x);
        }
    }

    void update(int i, int x) {
        _update(i + 1, x);
    }

    int get(int r) {
        int res = 0;
        for (; r > 0; r -= r & -r) {
            res = max(res, tree[r]);
        }
        return res;
    }
};

int longest_increasing_subsequence(const vector<int> &as, int N) {
    FenwickTree tree(N + 1);
    for (int i : as) {
        int value = tree.get(i) + 1;
        tree.update(i, value);
    }
    return tree.get(N + 1);
}

void solve() {
    int n; cin >> n;
    vector<int> as(n);
    for (int i = 0; i < n; i++) {
        cin >> as[i];
    }
    int L = longest_increasing_subsequence(as, n);
    if (L >= n - 1) {
        cout << n << endl;
        return;
    }
    int ptr = 0;
    while (ptr < n && (ptr == 0 || as[ptr] > as[ptr - 1])) {
        ptr++;
    }
    int L_prime = longest_increasing_subsequence(vector<int>(as.begin() + ptr, as.end()), n);
    if (L_prime + ptr == L) {
        cout << L + 1 << endl;
    } else {
        cout << L + 2 << endl;
    }
}

int main() {
    int t; cin >> t;
    while (t--) {
        solve();
    }
}
