#include <iostream>
#include <vector>
#include <algorithm>
#include <cassert>
#include <set>
#include <numeric>

using namespace std;

struct Segment {
    int l, r;
    explicit Segment() = default;
    Segment(int l_, int r_) : l(l_), r(r_) {

    }
    const bool contains(const Segment &other) const {
        return l <= other.l && other.r <= r && (l != other.l || r != other.r);
    }

    const bool operator==(const Segment &other) const {
        return l == other.l && r == other.r;
    }
};

const int INF = 1'000'000'007;

struct SegmentTree {
    vector<int> tree;
    int sz = 0;
    
    void build(const vector<int> &as, int v, int l, int r) {
        if (l + 1 == r) {
            tree[v] = as[l];
            return;
        }
        int m = (l + r) / 2;
        build(as, 2 * v + 1, l, m);
        build(as, 2 * v + 2, m, r);
        tree[v] = min(tree[2 * v + 1], tree[2 * v + 2]);
    }

    int get(int v, int l, int r, int ql, int qr) {
        if (l >= qr || ql >= r) {
            return INF;
        }
        if (ql <= l && r <= qr) {
            return tree[v];
        }
        int m = (l + r) / 2;
        return min(get(2 * v + 1, l, m, ql, qr), get(2 * v + 2, m, r, ql, qr));
    }

    SegmentTree(const vector<int> &as) {
        int n = as.size();
        tree.resize(4 * n + 5);
        sz = n;
        build(as, 0, 0, n);
    }

    int get(int ql, int qr) {
        if (ql >= qr) return INF;
        return get(0, 0, sz, ql, qr);
    }
};

void solve() {
    int n; cin >> n;
    vector<Segment> segs;
    for (int i = 0; i < n; i++) {
        int l, r; cin >> l >> r;
        segs.emplace_back(l, r);
    }
    vector<int> order(n);
    iota(order.begin(), order.end(), 0);
    sort(order.begin(), order.end(), [&](int i, int j) {
        return make_tuple(segs[i].l, -segs[i].r, i) < make_tuple(segs[j].l, -segs[j].r, j);
    });
    vector<int> rs(n);
    for (int i = 0; i < n; i++) {
        rs[i] = segs[order[i]].r;
    }
    SegmentTree st(rs);
    vector<pair<Segment, int>> new_segs;
    for (int i = 0; i < n; i++) {
        int lo = i, hi = n;
        while (hi - lo > 1) {
            int mid = (lo + hi) / 2;
            if (segs[order[mid]].l <= segs[order[i]].r) {
                lo = mid;
            } else {
                hi = mid;
            }
        }
        if (st.get(i + 1, hi) > segs[order[i]].r) {
            new_segs.emplace_back(segs[order[i]], order[i]);
        }
    }
    // for (int i = 0; i < n; i++) {
    //     bool inner = false;
    //     for (int j = 0; j < n && !inner; j++) {
    //         if (i == j) continue;
    //         if (segs[i].contains(segs[j]) || (segs[i] == segs[j] && i < j)) {
    //             inner = true;
    //         }
    //     }
    //     if (!inner) {
    //         new_segs.emplace_back(segs[i], i);
    //     }
    // }
    sort(new_segs.begin(), new_segs.end(), [](const auto &s1, const auto &s2) {
        return s1.first.l < s2.first.l;
    });
    vector<int> max_independent;
    int r = 0;
    int ptr = 0;
    int k = new_segs.size();
    while (ptr < k) {
        while (ptr < k && new_segs[ptr].first.l <= r) {
            ptr++;
        }
        if (ptr != k) {
            r = new_segs[ptr].first.r;
            max_independent.push_back(new_segs[ptr].second);
        }
    }
    int m = max_independent.size();
    int R = segs[max_independent[m / 2 - 1]].r, L = segs[max_independent[m / 2]].l;
    int bad_first = 0, bad_second = 0;
    for (const Segment &seg : segs) {
        if (seg.l >= R) {
            bad_first++;
        }
        if (seg.r <= L) {
            bad_second++;
        }
    }
    vector<bool> is_independent(n);
    for (int i : max_independent) {
        is_independent[i] = true;
    }
    if (bad_first <= n / 2) {
        int left = (n - m) / 2;
        for (int i = 0; i < n; i++) {
            if (segs[i].l >= R) continue;
            if (is_independent[i]) {
                cout << i + 1 << ' ';
            } else if (left > 0) {
                cout << i + 1 << ' ';
                left--;
            }
        }
    } else {
        int left = (n - m) / 2;
        for (int i = 0; i < n; i++) {
            if (segs[i].r <= L) continue;
            if (is_independent[i]) {
                cout << i + 1 << ' ';
            } else if (left > 0) {
                cout << i + 1 << ' ';
                left--;
            }
        }
    }
    cout << endl;
}

int main() {
    int t; cin >> t;
    while (t--) {
        solve();
    }
}
