#include <iostream>
#include <vector>
#include <algorithm>

using namespace std;

typedef long long ll;

//const int MAX = (1 << 30);
const int MAX = 32;

class SegmentTree {
private:
	struct Node {
		int l = -1, r = -1;
		int mx = 0, idx = 0;
		Node() {}
	};
	vector<Node> t;

	void push(int i) {
		if (t[i].l == -1) {
			t[i].l = t.size();
			t.push_back(Node());
			t[i].r = t.size();
			t.push_back(Node());
		}
	}
	
	void upd(int i, int l, int r, int q, int x, int idx) {
		push(i);
		if (q < l || q >= r)
			return;
		if (x > t[i].mx) {
			t[i].mx = x;
			t[i].idx = idx;
		}
		if (r - l == 1)
			return;
		int m = (l + r) / 2;
		upd(t[i].l, l, m, q, x, idx);
		upd(t[i].r, m, r, q, x, idx);
	}
	pair<int, int> get(int i, int l, int r, int ql, int qr) {
		push(i);
		if (qr <= l || r <= ql)
			return { -1, -1 };
		if (ql <= l && r <= qr)
			return { t[i].mx, t[i].idx };
		int m = (l + r) / 2;
		auto f1 = get(t[i].l, l, m, ql, qr);
		auto f2 = get(t[i].r, m, r, ql, qr);
		if (f1.first > f2.first)
			return f1;
		return f2;
	}

public:
	SegmentTree() {
	}
	void upd(int q, int x, int idx) {
		upd(1, 0, MAX, q, x, idx);
	}
	// [l ; r)
	pair<int, int> get(int ql, int qr) {
		return get(1, 0, MAX, ql, qr);
	}
};

struct Segment {
	int l = 0, r = 0;
	int idx = 0;

	bool operator <(const Segment& other) const {
		if (l == other.l)
			return r < other.r;
		return l < other.l;
	}

	Segment() {}
};

int dynamic(vector<Segment>& a, vector<int>& p, vector<int> dp) {
	SegmentTree t;
	for (int i = 0; i < a.size(); ++i) {
		auto res = t.get(0, a[i].l + 1);
		t.upd(a[i].r + 1, res.first + 1, i);
		p[i] = res.second;
		dp[i] = res.first + 1;
	}
	return t.get(0, MAX).second;
}

void solve() {
	int n;
	cin >> n;
	vector<Segment> a(n);
	for (int i = 0; i < n; ++i) {
		cin >> a[i].l >> a[i].r;
		a[i].idx = i + 1;
	}
	sort(a.begin(), a.end());
	for (int i = 0; i < n / 2; ++i) {
		cout << a[i].idx << " ";
	}
	cout << "\n";
}

int main() {
	ios_base::sync_with_stdio(false);
	cin.tie(0);
	cout.tie(0);

	int t;
	cin >> t;
	while (t--) {
		solve();
	}
}
